# remirepo spec file for php-pecl-parle
#
# Copyright (c) 2017-2021 Remi Collet
# License: CC-BY-SA
# http://creativecommons.org/licenses/by-sa/4.0/
#
# Please, preserve the changelog entries
#

# we don't want -z defs linker flag
%undefine _strict_symbol_defs_build

%if 0%{?scl:1}
%scl_package         php-pecl-parle
%global sub_prefix   %{scl_prefix}
%endif

%global with_zts     0%{!?_without_zts:%{?__ztsphp:1}}
%global with_tests   0%{!?_without_tests:1}
%global pecl_name    parle
# After json
%global ini_name     40-%{pecl_name}.ini

Summary:        Parsing and lexing
Name:           %{?sub_prefix}php-pecl-%{pecl_name}
Version:        0.8.1
Release:        9%{?dist}%{!?scl:%{!?nophptag:%(%{__php} -r 'echo ".".PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')}}
# Extension is BSD, libraries are Boost
License:        BSD and Boost
URL:            https://pecl.php.net/package/%{pecl_name}
Source0:        https://pecl.php.net/get/%{pecl_name}-%{version}.tgz

Patch0:         https://github.com/weltling/parle/commit/7c692b9880aa6a501b6627d923bbc8ed1da1465f.patch
Patch1:         https://patch-diff.githubusercontent.com/raw/weltling/parle/pull/17.patch
Patch2:         https://patch-diff.githubusercontent.com/raw/weltling/parle/pull/22.patch

BuildRequires:  make
%if 0%{?rhel} == 7 && 0%{?dtsversion} == 0
# Always use DTS as c++14 is required
BuildRequires: devtoolset-8-toolchain
%global dtsenable source /opt/rh/devtoolset-8/enable
%global dtsprefix devtoolset-8-
%endif
BuildRequires:  %{?dtsprefix}gcc
BuildRequires:  %{?dtsprefix}gcc-c++
BuildRequires:  %{?dtsprefix}libstdc++-devel
BuildRequires:  %{?scl_prefix}php-devel >= 7.0
BuildRequires:  %{?scl_prefix}php-pear
BuildRequires:  %{?scl_prefix}php-json

# bundled libraries
Provides:       bundled(parsertl)
Provides:       bundled(lexertl)

Requires:       %{?scl_prefix}php(zend-abi) = %{php_zend_api}
Requires:       %{?scl_prefix}php(api) = %{php_core_api}
Requires:       %{?scl_prefix}php-json%{?_isa}
%{?_sclreq:Requires: %{?scl_prefix}runtime%{?_sclreq}%{?_isa}}

Provides:       %{?scl_prefix}php-%{pecl_name}               = %{version}
Provides:       %{?scl_prefix}php-%{pecl_name}%{?_isa}       = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})         = %{version}
Provides:       %{?scl_prefix}php-pecl(%{pecl_name})%{?_isa} = %{version}
%if "%{?scl_prefix}" != "%{?sub_prefix}"
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}          = %{version}-%{release}
Provides:       %{?scl_prefix}php-pecl-%{pecl_name}%{?_isa}  = %{version}-%{release}
%endif

Obsoletes:     %{name}-devel < %{version}

%if "%{?packager}" == "Remi Collet" && 0%{!?scl:1} && 0%{?rhel}
%if "%{php_version}" > "7.3"
Obsoletes:     php73-pecl-%{pecl_name}  <= %{version}
%endif
%if "%{php_version}" > "7.4"
Obsoletes:     php74-pecl-%{pecl_name}  <= %{version}
%endif
%if "%{php_version}" > "8.0"
Obsoletes:     php80-pecl-%{pecl_name}  <= %{version}
%endif
%endif


%description
With Parle, it is possible to implement lexing and parsing in PHP
while relying on features and principles of the parser/lexer
generator tools for C/C++.

Documentation: http://php.net/parle

Package built for PHP %(%{__php} -r 'echo PHP_MAJOR_VERSION.".".PHP_MINOR_VERSION;')%{?scl: as Software Collection (%{scl} by %{?scl_vendor}%{!?scl_vendor:rh})}.


%prep
%setup -qc
mv %{pecl_name}-%{version} NTS

# Don't install/register tests
sed -e '/tests/s/role="test"/role="src"/'\
    -i package.xml

%if 0%{?_licensedir:1}
sed -e '/LICENSE/s/role="doc"/role="src"/;/licence/s/role="doc"/role="src"/' \
    -i package.xml
mv NTS/lib/lexertl14/lexertl/licence_1_0.txt   NTS/LICENSE.lexert14
mv NTS/lib/parsertl14/parsertl/licence_1_0.txt NTS/LICENSE.parsertl14
%endif

cd NTS
%patch0 -p1 -b .up
%patch1 -p1 -b .pr17
%patch2 -p1 -b .pr22

# Sanity check, really often broken
extver=$(sed -n '/#define PHP_PARLE_VERSION/{s/.* "//;s/".*$//;p}' php_parle.h)
if test "x${extver}" != "x%{version}%{?prever:-%{prever}}"; then
   : Error: Upstream extension version is ${extver}, expecting %{version}%{?prever:-%{prever}}.
   exit 1
fi
cd ..

%if %{with_zts}
# Duplicate source tree for NTS / ZTS build
cp -pr NTS ZTS
%endif

# Create configuration file
cat << 'EOF' | tee %{ini_name}
; Enable '%{summary}' extension module
extension=%{pecl_name}.so
EOF


%build
%{?dtsenable}

peclbuild() {
%configure \
    --enable-parle \
    --with-php-config=$1

make %{?_smp_mflags}
}

cd NTS
%{_bindir}/phpize
peclbuild %{_bindir}/php-config

%if %{with_zts}
cd ../ZTS
%{_bindir}/zts-phpize
peclbuild %{_bindir}/zts-php-config
%endif


%install
%{?dtsenable}

make -C NTS install INSTALL_ROOT=%{buildroot}

# install config file
install -D -m 644 %{ini_name} %{buildroot}%{php_inidir}/%{ini_name}

# Install XML package description
install -D -m 644 package.xml %{buildroot}%{pecl_xmldir}/%{name}.xml

%if %{with_zts}
make -C ZTS install INSTALL_ROOT=%{buildroot}

install -D -m 644 %{ini_name} %{buildroot}%{php_ztsinidir}/%{ini_name}
%endif

# Documentation
for i in $(grep 'role="doc"' package.xml | sed -e 's/^.*name="//;s/".*$//')
do install -Dpm 644 NTS/$i %{buildroot}%{pecl_docdir}/%{pecl_name}/$i
done


%check
export NO_INTERACTION=1
export REPORT_EXIT_STATUS=1

: Minimal load test for NTS extension
cd NTS
%{__php} --no-php-ini \
    --define extension=%{buildroot}%{php_extdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with_tests}
: Upstream test suite
make test "TESTS=--show-diff"
%endif

%if %{with_zts}
cd ../ZTS
: Minimal load test for ZTS extension
%{__ztsphp} --no-php-ini \
    --define extension=%{buildroot}%{php_ztsextdir}/%{pecl_name}.so \
    --modules | grep %{pecl_name}

%if %{with_tests}
: Upstream test suite
make test "TESTS=--show-diff"
%endif
%endif


%if 0%{?fedora} < 24 && 0%{?rhel} < 8
# when pear installed alone, after us
%triggerin -- %{?scl_prefix}php-pear
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

# posttrans as pear can be installed after us
%posttrans
if [ -x %{__pecl} ] ; then
    %{pecl_install} %{pecl_xmldir}/%{name}.xml >/dev/null || :
fi

%postun
if [ $1 -eq 0 -a -x %{__pecl} ] ; then
    %{pecl_uninstall} %{pecl_name} >/dev/null || :
fi
%endif


%files
%{?_licensedir:%license NTS/LICENSE*}
%doc %{pecl_docdir}/%{pecl_name}
%{pecl_xmldir}/%{name}.xml

%config(noreplace) %{php_inidir}/%{ini_name}
%{php_extdir}/%{pecl_name}.so

%if %{with_zts}
%config(noreplace) %{php_ztsinidir}/%{ini_name}
%{php_ztsextdir}/%{pecl_name}.so
%endif


%changelog
* Fri Jan 15 2021 Remi Collet <remi@remirepo.net> - 0.8.1-9
- add patch for 8.0 from
  https://github.com/weltling/parle/pull/22

* Tue Sep 03 2019 Remi Collet <remi@remirepo.net> - 0.8.1-8
- rebuild for 7.4.0RC1

* Fri Aug 23 2019 Remi Collet <remi@remirepo.net> - 0.8.1-7
- add patch for 7.4 from
  https://github.com/weltling/parle/pull/17

* Tue Jun  4 2019 Remi Collet <remi@remirepo.net> - 0.8.1-6
- add upstream patch for 7.4

* Wed Dec 12 2018 Remi Collet <remi@remirepo.net> - 0.8.1-5
- cleanup for EL-8

* Thu Aug 16 2018 Remi Collet <remi@remirepo.net> - 0.8.1-4
- rebuild for 7.3.0beta2 new ABI

* Wed Jul 18 2018 Remi Collet <remi@remirepo.net> - 0.8.1-3
- rebuild for 7.3.0alpha4 new ABI

* Mon Mar  5 2018 Remi Collet <remi@remirepo.net> - 0.8.1-1
- Update to 0.8.1

* Thu Mar  1 2018 Remi Collet <remi@remirepo.net> - 0.7.3-2
- add patch to fix build with gcc 8
  from https://github.com/weltling/parle/pull/13

* Sun Nov 12 2017 Remi Collet <remi@remirepo.net> - 0.7.3-1
- Update to 0.7.3

* Mon Oct 30 2017 Remi Collet <remi@remirepo.net> - 0.7.1-1
- Update to 0.7.1

* Mon Oct  2 2017 Remi Collet <remi@remirepo.net> - 0.7.0-1
- Update to 0.7.0

* Fri Sep 29 2017 Remi Collet <remi@remirepo.net> - 0.6.5-1
- Update to 0.6.5

* Tue Sep 26 2017 Remi Collet <remi@remirepo.net> - 0.6.4-1
- Update to 0.6.4

* Sat Sep 23 2017 Remi Collet <remi@remirepo.net> - 0.6.3-1
- Update to 0.6.3

* Wed Sep 20 2017 Remi Collet <remi@remirepo.net> - 0.6.2-1
- Update to 0.6.2

* Mon Sep 18 2017 Remi Collet <remi@remirepo.net> - 0.6.1-1
- Update to 0.6.1

* Sun Sep 17 2017 Remi Collet <remi@remirepo.net> - 0.6.0-1
- Update to 0.6.0

* Sat Sep  9 2017 Remi Collet <remi@remirepo.net> - 0.5.3-1
- Update to 0.5.3
- open https://github.com/weltling/parle/pull/8 - cxx extension

* Sat Sep  9 2017 Remi Collet <remi@remirepo.net> - 0.5.2-1
- Update to 0.5.2
- drop devel sub-package
- open https://github.com/weltling/parle/pull/7 - PHP 7.2 build error

* Sat Sep  9 2017 Remi Collet <remi@remirepo.net> - 0.5.1-1
- initial package, version 0.5.1 (alpha)
- open https://github.com/BenHanson/parsertl14/issues/1 license file
- open https://github.com/weltling/parle/pull/1 missing license file
- open https://github.com/weltling/parle/pull/2 fix roles
- open https://github.com/weltling/parle/issues/3 is header needed
